# gada

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gada)
[![Python package](https://img.shields.io/github/workflow/status/gadalang/gada/Python%20package)](https://github.com/gadalang/gada/actions/workflows/python-package.yml)
[![Documentation Status](https://readthedocs.org/projects/gada/badge/?version=latest)](https://gada.readthedocs.io/en/latest/?badge=latest)
[![Codecov](https://img.shields.io/codecov/c/gh/gadalang/gada?token=FDUD389KFM)](https://codecov.io/gh/gadalang/gada)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/gadalang/gada/issues)

gada is a python package and command line tool that let you run code written in any language through a common interface.

## Install

Using pip:

```bash
$ pip3 install gada
```

## Documentation

Build the doc with:

```bash
$ make html
```

You can find the latest documentation on [gada.readthedocs.io](https://gada.readthedocs.io/).

## Testing

The `test` directory contains many tests that you can run with:

```python
$ tox .
```

## License

Licensed under the [MIT](LICENSE) License.
